package com.bizmatics.mhfire.controller.web;

import com.bizmatics.common.core.bean.ApiResult;
import com.bizmatics.common.core.bean.CommonPage;
import com.bizmatics.mhfire.persistence.mapper.po.FireStatisticsPO;
import com.bizmatics.mhfire.service.FireStatisticsService;
import com.bizmatics.mhfire.service.vo.FireLevelRatioVO;
import com.bizmatics.mhfire.service.vo.FireUnitPoliceVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @author yq
 * @date 2021/5/31 10:20
 * 火灾详情
 */
@RestController
@RequestMapping("/fireStatistics")
public class FireStatisticsControllerWeb {


    @Autowired
    private FireStatisticsService fireStatisticsService;


    /**
     * 根据年份和地址查看12月份的火灾统计
     * @param year 年份
     * @param address 地址
     * @return
     */
    @GetMapping("fireCountByData")
    public ApiResult<List<Integer>> getFireCountByData(@RequestParam Integer year,
                                                       @RequestParam(required = false)String address){
        return ApiResult.success(fireStatisticsService.getFireCountByData(year, address));
    }


    /**
     * 分页
     * @param current 页数
     * @param size 条数
     * @param startTime 开始时间
     * @param endTime 结束时间
     * @param address 地址
     * @return
     */
    @GetMapping("page")
    public ApiResult<CommonPage<FireStatisticsPO>> page(@RequestParam Integer current,
                                                        @RequestParam Integer size,
                                                        @RequestParam(required = false)String startTime,
                                                        @RequestParam(required = false)String endTime,
                                                        @RequestParam(required = false)String address){
        return ApiResult.success(fireStatisticsService.page(current, size, startTime, endTime, address));
    }


    /**
     * getOne
     * @param id
     * @return
     */
    @GetMapping("one")
    public ApiResult<FireStatisticsPO> getOne(@RequestParam String id){
        return ApiResult.success(fireStatisticsService.getOne(id));
    }


    /**
     * 火灾-单位-出警信息
     * @param id
     * @return
     */
    @GetMapping("fireUnitPolice")
    public ApiResult<FireUnitPoliceVO> getFireUnitPolice(@RequestParam String id){
        return ApiResult.success(fireStatisticsService.getFireUnitPolice(id));
    }


    /**
     * 火灾原因占比
     * @param startTime 开始时间
     * @param endTime   结束时间
     * @param address   地址
     * @return
     */
    @GetMapping("fireCauseRatio")
    public ApiResult<List<FireLevelRatioVO>> getGroupByLevel(@RequestParam(required = false) String startTime,
                                                             @RequestParam(required = false)String endTime,
                                                             @RequestParam(required = false)String address){
        return ApiResult.success(fireStatisticsService.getGroupByLevel(startTime,endTime,address));
    }
}
